/* Public domain. */

#ifndef DNS_TRANSMIT_H
#define DNS_TRANSMIT_H

#include "tai.h"
#include "iopause.h"
#include "stralloc.h"

struct dns_transmit
{
  char *query ; /* 0, or dynamically allocated */
  unsigned int querylen ;
  char *packet ; /* 0, or dynamically allocated */
  unsigned int packetlen ;
  int s1 ; /* 0, or 1 + an open file descriptor */
  int tcpstate ;
  unsigned int udploop ;
  unsigned int curserver ;
  struct taia deadline ;
  unsigned int pos ;
  char const *servers ;
  char localip[4] ;
  char qtype[2] ;
} ;

#define DNS_TRANSMIT_ZERO {0, 0, 0, 0, 0, 0, 0, 0, TAIA_ZERO, 0, 0, "\0\0\0", "\0"}

extern int dns_transmit_start (struct dns_transmit *, char const *, int, char const *, char const *, char const *) ;
extern void dns_transmit_free (struct dns_transmit *) ;
extern void dns_transmit_io (struct dns_transmit *, iopause_fd *, struct taia *) ;
extern int dns_transmit_get (struct dns_transmit *, iopause_fd const *, struct taia const *) ;

extern int dns_resolvconfip (char *) ;
extern int dns_resolve (char const *, char const *) ;
extern struct dns_transmit dns_resolve_tx ;
extern int dns_resolve_r (struct dns_transmit *, char const *, char const *) ;

extern int dns_ip4 (stralloc *, stralloc const *) ;
extern int dns_name4 (stralloc *, char const *) ;
extern int dns_txt (stralloc *, stralloc const *) ;
extern int dns_mx (stralloc *, stralloc const *) ;

extern int dns_ip4_qualify (stralloc *, stralloc *, stralloc const *) ;
extern int dns_ip4_qualify_rules (stralloc *, stralloc *, stralloc const *, stralloc const *) ;
extern int dns_resolvconfrewrite (stralloc *) ;                                 

#endif
